@@ -10,7 +10,7 @@ $LastChangedRevision$
 
 =head1 DATE
 
-$LastChangedDate: 2005-08-30 04:41:59 -0700 (Tue, 30 Aug 2005) $
+$LastChangedDate: 2006-08-03 00:48:16 +0200 (Thu, 03 Aug 2006) $
 
 =head1 DESCRIPTION
 
@@ -132,8 +132,7 @@ sub read_modules {
     while ($data =~ /^\s*(\w+)\.c\s*$/mg) {
         $AP{static_modules}{$1} = 1;
     }
-    hard_fail("Unable to extract static modules from ",
-              "`$REQ->{APACHE_EXE} -V`.")
+    hard_fail("Unable to extract static modules from `$REQ->{APACHE_EXE} -l`.")
         unless exists $AP{static_modules}{http_core};
 
     # set dso flag of mod_so.c is compiled in
