@@ -10,7 +10,7 @@ $LastChangedRevision$
 
 =head1 DATE
 
-$LastChangedDate: 2006-05-25 11:23:06 -0700 (Thu, 25 May 2006) $
+$LastChangedDate: 2006-08-03 00:46:02 +0200 (Thu, 03 Aug 2006) $
 
 =head1 DESCRIPTION
 
@@ -27,7 +27,6 @@ L<Bric::Admin>
 
 =cut
 
-
 use strict;
 use FindBin;
 use lib "$FindBin::Bin/lib";
@@ -41,9 +40,19 @@ print "\n\n==> Cloning Bricolage Database <==\n\n";
 our $PG;
 do "./postgres.db" or die "Failed to read postgres.db: $!";
 
+# Make sure that we don't overwrite the existing Pg.sql.
+chdir 'dist';
+
 # Switch to postgres system user
 if (my $sys_user = $PG->{system_user}) {
     print "Becoming $sys_user...\n";
+
+    # Make sure that the user can write out inst/Pg.sql.
+    my $file = -e 'inst/Pg.sql' ? 'inst/Pg.sql' : 'inst';
+    chown $PG->{system_user_uid}, -1, $file
+        or die "Cannot chown $file to $PG->{system_user_uid} ($sys_user).\n";
+
+    # Become the user.
     $> = $PG->{system_user_uid};
     die "Failed to switch EUID to $PG->{system_user_uid} ($sys_user).\n"
         unless $> == $PG->{system_user_uid};
