@@ -18,7 +18,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-06-13 16:06:11 -0700 (Tue, 13 Jun 2006) $
+$LastChangedDate: 2006-06-14 01:06:11 +0200 (Wed, 14 Jun 2006) $
 
 =head1 DESCRIPTION
 
