@@ -4,22 +4,23 @@ use strict;
 use warnings;
 use base qw(Bric::Test::DevBase);
 use Test::More;
-use Bric::Util::Grp::Org;
 use Bric::Biz::Org;
+use Bric::Util::Grp::Org;
+use Bric::Util::DBI 'ANY';
 use Bric::Util::Grp::Person;
 use Bric::Util::Grp::User;
 use Bric::Util::Grp::AlertType;
 use Bric::Util::Grp::Asset;
-use Bric::Util::Grp::AssetType;
+use Bric::Util::Grp::ElementType;
 use Bric::Util::Grp::AssetVersion;
 use Bric::Util::Grp::CategorySet;
 use Bric::Util::Grp::ContribType;
 use Bric::Util::Grp::Desk;
 use Bric::Util::Grp::Dest;
-use Bric::Util::Grp::Element;
-use Bric::Util::Grp::ElementType;
+use Bric::Util::Grp::SubelementType;
+use Bric::Util::Grp::ATType;
 use Bric::Util::Grp::Event;
-use Bric::Util::Grp::Formatting;
+use Bric::Util::Grp::Template;
 use Bric::Util::Grp::Grp;
 use Bric::Util::Grp::Job;
 use Bric::Util::Grp::Keyword;
@@ -33,7 +34,7 @@ use Bric::Util::Grp::Site;
 use Bric::Util::Grp::Source;
 use Bric::Util::Grp::Story;
 use Bric::Util::Grp::Workflow;
-use Bric::Biz::AssetType;
+use Bric::Biz::ElementType;
 
 sub table { 'grp' }
 
@@ -72,7 +73,7 @@ sub test_lookup : Test(20) {
 
 ##############################################################################
 # Test the list() method.
-sub test_list : Test(40) {
+sub test_list : Test(70) {
     my $self = shift;
     ok( my @grps = Bric::Util::Grp->list({ name => 'All%' }),
         "get all All groups" );
@@ -94,6 +95,18 @@ sub test_list : Test(40) {
     "Check 'All Preferences' class" );
     is( $grps[0]->get_name, 'All Preferences', "Check 'All Preferences' name" );
 
+    ok( @grps = Bric::Util::Grp::Pref->list({
+        obj_id => ANY(1, 2, 3),
+        package => 'Bric::Util::Pref'
+    }), "get any groups with prefs 1, 2, or 3 in them" );
+    is( scalar @grps, 1, "Check for one 'Pref' group" );
+
+    ok( @grps = Bric::Util::Grp::Org->list({
+        obj => ANY(Bric::Biz::Org->lookup({ id => 1 })),
+        package => 'Bric::Util::Org'
+    }), "get any groups with org 1 object in them, using ANY" );
+    is( scalar @grps, 1, "Check for one 'Org' group" );
+
     # Create a new group group.
     ok( my $grpgrp = Bric::Util::Grp::Grp->new
         ({ name => 'Test GrpGrp' }),
@@ -121,11 +134,32 @@ sub test_list : Test(40) {
         "Look up name $grp{name}" );
     is( scalar @grps, 2, "Check for 2 groups" );
 
+    # Try ANY(name)
+    ok( @grps = Bric::Util::Grp->list({ name => ANY($grp{name}, "$grp{name}1") }),
+        "Look up name ANY($grp{name}, $grp{name}1)" );
+    is( scalar @grps, 3, "Check for 3 groups" );
+
     # Try name + wildcard.
     ok( @grps = Bric::Util::Grp->list({ name => "$grp{name}%" }),
         "Look up name $grp{name}%" );
     is( scalar @grps, 5, "Check for 5 groups" );
 
+    # Try description.
+    ok( @grps = Bric::Util::Grp->list({ description => $grp{description} }),
+        "Look up description $grp{description}" );
+    is( scalar @grps, 5, "Check for 5 groups" );
+
+    # Try description + wildcard.
+    ok( @grps = Bric::Util::Grp->list({ description => "Users%" }),
+        "Look up description Users%" );
+    is( scalar @grps, 7, "Check for 7 groups" );
+
+    # Try ANY(description)
+    ok( @grps = Bric::Util::Grp->list({
+        description => ANY($grp{description}, "Users%")
+    }), "Look up description ANY($grp{description}, Users%" );
+    is( scalar @grps, 12, "Check for 12 groups" );
+
     # Try grp_id.
     ok( @grps = Bric::Util::Grp->list({ grp_id => $grp_id }),
         "Look up grp_id '$grp_id'" );
@@ -138,6 +172,11 @@ sub test_list : Test(40) {
           "Check for both IDs" );
     }
 
+    # Try ANY(grp_id).
+    ok( @grps = Bric::Util::Grp->list({ grp_id => ANY($grp_id) }),
+        "Look up grp_id 'ANY($grp_id)'" );
+    is( scalar @grps, 3, "Check for 3 groups" );
+
     # Try deactivating one group membership.
     ok( my $mem = $grpgrp->has_member({ obj => $grps[0] }), "Get member" );
     ok( $mem->deactivate->save, "Deactivate and save member" );
@@ -152,6 +191,38 @@ sub test_list : Test(40) {
     ok( @grps = Bric::Util::Grp::Grp->list({ obj => $grps[0], all => 1 }),
         "Look up for group ID $gid" );
     is( scalar @grps, 2, "Check for 2 groups" );
+
+    # Try ANY(id).
+    ok( @grps = Bric::Util::Grp->list({ id => ANY(1, 2) }),
+        "Look up for id => ANY(1, 2)" );
+    is( scalar @grps, 2, "Check for 2 groups" );
+
+    # Try parent_id.
+    ok( @grps = Bric::Util::Grp->list({ parent_id => 0 }),
+        "Look up for parent_id => 0" );
+    is( scalar @grps, 7, "Check for 7 groups" );
+
+    # Try ANY(parent_id).
+    ok( @grps = Bric::Util::Grp->list({ parent_id => ANY(0) }),
+        "Look up for parent_id => ANY(0)" );
+    is( scalar @grps, 7, "Check for 7 groups" );
+
+    # Try deactivating one group.
+    ok my ($tmpgrp) = Bric::Util::Grp->list({ name => "$grp{name}1"}),
+      "Get one group.";
+    ok $tmpgrp->deactivate, "Deactivate group";
+    ok $tmpgrp->save, "Save deactivated group";
+    @grps = Bric::Util::Grp->list({ name => "$grp{name}1"});
+    is @grps, 0, "Should not find deactivated group";
+    ok @grps = Bric::Util::Grp->list({ name => "$grp{name}1", inactive => 1}),
+      "...Unless we use inactive => 1";
+    is @grps, 1, "We should have the one deactivated group";
+    ok @grps = Bric::Util::Grp->list({ name => "$grp{name}1", active => 0}),
+      "...Or unless we use active => 0";
+    is @grps, 1, "We should have the one deactivated group";
+    ok @grps = Bric::Util::Grp->list({ name => "$grp{name}%", active => undef}),
+      "...And we should get both if active => undef";
+    is @grps, 5, "We should have 5 groups";
 }
 
 ##############################################################################
@@ -199,7 +270,7 @@ sub test_members : Test(36) {
 
     # Now test the get_members method.
     ok( my @mems = $grp->get_members, "Get pref members" );
-    is( scalar @mems, 12, "Check number of pref mems" );
+    is( scalar @mems, 14, "Check number of pref mems" );
     ok( my ($mem) = (grep { $_->get_id == 401 } @mems), "Get tz member" );
     ok( UNIVERSAL::isa($mem, 'Bric::Util::Grp::Parts::Member'),
         "Check tz member class" );
@@ -210,14 +281,14 @@ sub test_members : Test(36) {
     # Try deleting a member.
     ok( $grp->delete_member($mem), "Delete Member" );
     ok( @mems = $grp->get_members, "Get pref members again" );
-    is( scalar @mems, 11, "Check number of pref mems 2" );
+    is( scalar @mems, 13, "Check number of pref mems 2" );
     ok( ! (grep { $_->get_id == 401 } @mems), "Don't get tz member" );
 
     # Now add the member back.
     ok( $grp->add_member({ package => 'Bric::Util::Pref', id => 1 }),
         "Add the preference again" );
     ok( @mems = $grp->get_members, "Get pref members 3" );
-    is( scalar @mems, 12, "Check number of pref mems 3" );
+    is( scalar @mems, 14, "Check number of pref mems 3" );
 
     # Play around with has_member().
     ok( $grp->has_member({ package => 'Bric::Util::Pref', id => 2 }),
@@ -228,28 +299,26 @@ sub test_members : Test(36) {
     # Now try an element group.
     my $story_elem_grp_id = 330;
     ok( $grp = Bric::Util::Grp->lookup({ id => $story_elem_grp_id }),
-        "Look up story element group" );
-    isa_ok($grp, "Bric::Util::Grp::AssetType");
-    ok( @mems = $grp->get_members, "Get story element members" );
-    is( scalar @mems, 2, "Check number of story element mems" );
+        "Look up story subelement type group" );
+    isa_ok($grp, "Bric::Util::Grp::SubelementType");
+    ok( @mems = $grp->get_members, "Get story subelement type grp members" );
+    is( scalar @mems, 2, "Check number of story subelement type grp mems" );
 
     # Add a new element to the group.
-    ok my $et = Bric::Biz::AssetType->new({
+    ok my $et = Bric::Biz::ElementType->new({
         name          => 'Test Element',
         key_name      => 'test_element',
         description   => 'Testing Element API',
-        burner        => Bric::Biz::AssetType::BURNER_MASON,
-        type__id      => 1,
-        reference     => 0,
+        top_level     => 1,
         primary_oc_id => 1,
     }), 'Create new element type';
     ok $et->save, 'Save it';
     ok my $et_id = $et->get_id, 'Get element type id';
-    $self->add_del_ids($et_id, 'element');
+    $self->add_del_ids($et_id, 'element_type');
 
     ok $grp->add_member({
         id      => $et_id,
-        package => 'Bric::Biz::AssetType',
+        package => ref $et,
     }), 'Add test element to group';
     ok $grp->save, 'Save element group';
 
@@ -283,7 +352,7 @@ sub test_get_objects : Test(8) {
 
     # Now get the objects.
     ok( my @prefs = $grp->get_objects, "Get pref objects" );
-    is( scalar @prefs, 12, "Check number of pref mems" );
+    is( scalar @prefs, 14, "Check number of pref mems" );
     isa_ok( $prefs[0], 'Bric::Util::Pref' );
 
     # Try an element group, just for the heck of it.
@@ -292,7 +361,7 @@ sub test_get_objects : Test(8) {
         "Look up story element group" );
     ok( my @ats = $grp->get_objects, "Get story element objects" );
     is( scalar @ats, 2, "Check number of story elements" );
-    isa_ok( $ats[0], 'Bric::Biz::AssetType');
+    isa_ok( $ats[0], 'Bric::Biz::ElementType');
 }
 
 ##############################################################################
